<?php

namespace Drupal\search_365\SearchResults;

/**
 * Defines a value object for creating a search.
 */
class SearchQuery {

  /**
   * Search query.
   *
   * @var string
   */
  protected $query;

  /**
   * Number of results.
   *
   * @var int
   */
  protected $size;

  /**
   * Page number.
   *
   * @var int
   */
  protected $pageNum;

  /**
   * Constructs a new SearchQuery object.
   *
   * @param string $query
   *   Search terms.
   * @param int $pageNum
   *   Results page.
   * @param int $size
   *   Number of results.
   */
  public function __construct($query, $pageNum = 1, $size = 10) {
    $this->query = $query;
    $this->pageNum = $pageNum;
    $this->size = $size;
  }

  /**
   * Gets value of searchQuery.
   *
   * @return string
   *   Value of searchQuery
   */
  public function getQuery() {
    return $this->query;
  }

  /**
   * Gets value of page.
   *
   * @return int
   *   Value of page
   */
  public function getPageNum() {
    return $this->pageNum;
  }

  /**
   * Gets number of results.
   *
   * @return int
   *   Returns number of results.
   */
  public function getSize(): int {
    return $this->size;
  }

}
